@@ -51,6 +51,7 @@ def start_multithreaded_batch_worker(
     log_level: str,
     benchmark: bool,
     batch_id: str,
+    batch_interval: float,
 ) -> None:
     """
     Starts the multithreaded batch worker which consists of three worker types and
@@ -98,7 +99,17 @@ def start_multithreaded_batch_worker(
     for _ in range(workers):
         Thread(
             target=_start_request_worker,
-            args=(q_in, q_out, data_type, sc, method, retries, batch_id, payload_type),
+            args=(
+                q_in,
+                q_out,
+                data_type,
+                sc,
+                method,
+                retries,
+                batch_id,
+                payload_type,
+                batch_interval,
+            ),
             daemon=True,
         ).start()
 
@@ -195,6 +206,7 @@ def _start_request_worker(
     retries: int,
     batch_id: str,
     payload_type: str,
+    batch_interval: float,
 ) -> None:
     """
     Runs logic for the worker that sends requests from the queue until the queue
@@ -219,6 +231,7 @@ def _start_request_worker(
         The unique identifier for the batch which is passed to all requests
     """
     while True:
+        start_time = time.time()
         input_data = q_in.get()
         if method == "predict":
             # If we have a batch size > 1 then we wish to use the method for sending multiple predictions
@@ -258,6 +271,13 @@ def _start_request_worker(
                 batch_id,
             )
             q_out.put(str_output)
+
+        # Setting time interval before the task is marked as done
+        if batch_interval > 0:
+            remaining_interval = batch_interval - (time.time() - start_time)
+            if remaining_interval > 0:
+                time.sleep(remaining_interval)
+
         # Mark task as done in the queue to add space for new tasks
         q_in.task_done()
 
@@ -649,12 +669,20 @@ def _send_batch_feedback(
 )
 @click.option(
     "--batch-size",
-    "-u",
+    "-s",
     envvar="SELDON_BATCH_SIZE",
     default=1,
     type=int,
     help="Batch size greater than 1 can be used to group multiple predictions into a single request.",
 )
+@click.option(
+    "--batch-interval",
+    "-t",
+    envvar="SELDON_BATCH_MIN_INTERVAL",
+    default=0,
+    type=float,
+    help="Minimum Time interval(in seconds) between batch predictions made by every worker",
+)
 def run_cli(
     deployment_name: str,
     gateway_type: str,
@@ -672,6 +700,7 @@ def run_cli(
     log_level: str,
     benchmark: bool,
     batch_id: str,
+    batch_interval: float,
 ):
     """
     Command line interface for Seldon Batch Processor, which can be used to send requests
@@ -701,6 +730,7 @@ def run_cli(
         log_level,
         benchmark,
         batch_id,
+        batch_interval,
     )
 
 
