@@ -10,6 +10,14 @@ from google.protobuf import any_pb2, json_format
 from google.protobuf.json_format import MessageToDict, ParseDict
 from google.protobuf.struct_pb2 import ListValue
 
+from seldon_core.env_utils import (
+    ENV_MODEL_IMAGE,
+    ENV_MODEL_NAME,
+    NONIMPLEMENTED_IMAGE_MSG,
+    NONIMPLEMENTED_MSG,
+    get_image_name,
+    get_model_name,
+)
 from seldon_core.flask_utils import SeldonMicroserviceException
 from seldon_core.imports_helper import _TF_PRESENT
 from seldon_core.proto import prediction_pb2
@@ -27,19 +35,11 @@ if _TF_PRESENT:
 logger = logging.getLogger(__name__)
 
 
-ENV_MODEL_NAME = "PREDICTIVE_UNIT_ID"
-ENV_MODEL_IMAGE = "PREDICTIVE_UNIT_IMAGE"
-NONIMPLEMENTED_MSG = "NOT_IMPLEMENTED"
-
-model_name = os.environ.get(ENV_MODEL_NAME, f"{NONIMPLEMENTED_MSG}")
-image_name = os.environ.get(
-    ENV_MODEL_IMAGE, f"{NONIMPLEMENTED_MSG}:{NONIMPLEMENTED_MSG}"
-)
-
-
 def get_request_path():
+    model_name = get_model_name()
     if model_name == NONIMPLEMENTED_MSG:
         return {}
+    image_name = get_image_name()
     return {model_name: image_name}
 
 
@@ -164,6 +164,7 @@ def feedback_to_json(message_proto: prediction_pb2.Feedback) -> Dict:
     ----------
     message_proto
        SeldonMessage proto
+
     Returns
     -------
        JSON Dict
@@ -348,6 +349,7 @@ def array_to_list_value(array: np.ndarray, lv: Optional[ListValue] = None) -> Li
 
     Returns
     -------
+    ListValue protobuf
 
     """
     if lv is None:
