@@ -2,9 +2,9 @@ import base64
 import io
 import json
 import logging
-from unittest import mock
 
 import numpy as np
+import pytest
 from google.protobuf import json_format
 from PIL import Image
 
@@ -45,7 +45,7 @@ def rs232_checksum(the_bytes):
 
 
 class UserObject(SeldonComponent):
-    HEALTH_STATUS_REPONSE = [0.123]
+    HEALTH_STATUS_RESPONSE = [0.123]
     METADATA_RESPONSE = {
         "name": "my-model-name",
         "versions": ["model-version"],
@@ -98,7 +98,7 @@ class UserObject(SeldonComponent):
             return [{"type": "BAD", "key": "mycounter", "value": 1}]
 
     def health_status(self):
-        return self.predict(self.HEALTH_STATUS_REPONSE, ["some_float"])
+        return self.predict(self.HEALTH_STATUS_RESPONSE, ["some_float"])
 
     def init_metadata(self):
         return self.METADATA_RESPONSE
@@ -240,6 +240,22 @@ class UserObjectLowLevelGrpc(SeldonComponent):
         logging.info("Feedback called")
 
 
+@pytest.fixture(name="mock_get_model_name")
+def fixture_get_model_name(mocker):
+    return mocker.patch(
+        "seldon_core.utils.get_model_name", autospec=True, return_value="my-test-model"
+    )
+
+
+@pytest.fixture(name="mock_get_image_name")
+def fixture_get_image_name(mocker):
+    return mocker.patch(
+        "seldon_core.utils.get_image_name",
+        autospec=True,
+        return_value="my-test-model-image",
+    )
+
+
 def test_model_ok():
     user_object = UserObject()
     seldon_metrics = SeldonMetrics()
@@ -311,9 +327,7 @@ def test_model_puid_ok():
     assert j["meta"]["puid"] == "123"
 
 
-@mock.patch("seldon_core.utils.model_name", "my-test-model")
-@mock.patch("seldon_core.utils.image_name", "my-test-model-image")
-def test_requestPath_ok():
+def test_requestPath_ok(mock_get_model_name, mock_get_image_name):
     user_object = UserObject()
     seldon_metrics = SeldonMetrics()
     app = get_rest_microservice(user_object, seldon_metrics)
@@ -327,9 +341,7 @@ def test_requestPath_ok():
     assert j["meta"]["requestPath"] == {"my-test-model": "my-test-model-image"}
 
 
-@mock.patch("seldon_core.utils.model_name", "my-test-model")
-@mock.patch("seldon_core.utils.image_name", "my-test-model-image")
-def test_requestPath_2nd_node_ok():
+def test_requestPath_2nd_node_ok(mock_get_model_name, mock_get_image_name):
     user_object = UserObject()
     seldon_metrics = SeldonMetrics()
     app = get_rest_microservice(user_object, seldon_metrics)
@@ -346,9 +358,7 @@ def test_requestPath_2nd_node_ok():
     }
 
 
-@mock.patch("seldon_core.utils.model_name", "my-test-model")
-@mock.patch("seldon_core.utils.image_name", "my-test-model-image")
-def test_proto_requestPath_ok():
+def test_proto_requestPath_ok(mock_get_model_name, mock_get_image_name):
     user_object = UserObject()
     seldon_metrics = SeldonMetrics()
     app = SeldonModelGRPC(user_object, seldon_metrics)
@@ -366,9 +376,7 @@ def test_proto_requestPath_ok():
     assert j["meta"]["requestPath"] == {"my-test-model": "my-test-model-image"}
 
 
-@mock.patch("seldon_core.utils.model_name", "my-test-model")
-@mock.patch("seldon_core.utils.image_name", "my-test-model-image")
-def test_proto_requestPath_2nd_node_ok():
+def test_proto_requestPath_2nd_node_ok(mock_get_model_name, mock_get_image_name):
     user_object = UserObject()
     seldon_metrics = SeldonMetrics()
     app = SeldonModelGRPC(user_object, seldon_metrics)
@@ -795,7 +803,7 @@ def test_model_health_status():
     assert rv.status_code == 200
     j = json.loads(rv.data)
     logging.info(j)
-    assert j["data"]["tensor"]["values"] == UserObject.HEALTH_STATUS_REPONSE
+    assert j["data"]["tensor"]["values"] == UserObject.HEALTH_STATUS_RESPONSE
 
 
 def test_model_health_status_raw():
