@@ -1,4 +1,5 @@
 import base64
+import json
 import logging
 import pickle
 
@@ -8,6 +9,20 @@ from google.protobuf import any_pb2
 from google.protobuf.struct_pb2 import Value
 
 import seldon_core.utils as scu
+from seldon_core.env_utils import (
+    ENV_MODEL_IMAGE,
+    ENV_MODEL_NAME,
+    ENV_PREDICTOR_LABELS,
+    ENV_PREDICTOR_NAME,
+    ENV_SELDON_DEPLOYMENT_NAME,
+    NONIMPLEMENTED_IMAGE_MSG,
+    NONIMPLEMENTED_MSG,
+    get_deployment_name,
+    get_image_name,
+    get_model_name,
+    get_predictor_name,
+    get_predictor_version,
+)
 from seldon_core.flask_utils import SeldonMicroserviceException
 from seldon_core.imports_helper import _TF_PRESENT
 from seldon_core.proto import prediction_pb2
@@ -64,7 +79,7 @@ class UserObject:
             return [{"type": "BAD", "key": "mycounter", "value": 1}]
 
 
-def test_create_rest_reponse_nparray():
+def test_create_rest_response_nparray():
     user_model = UserObject()
     request = {}
     raw_response = np.array([[1, 2, 3]])
@@ -73,7 +88,7 @@ def test_create_rest_reponse_nparray():
     assert result["data"]["tensor"]["values"] == [1, 2, 3]
 
 
-def test_create_grpc_reponse_nparray():
+def test_create_grpc_response_nparray():
     user_model = UserObject()
     request = prediction_pb2.SeldonMessage()
     raw_response = np.array([[1, 2, 3]])
@@ -82,7 +97,7 @@ def test_create_grpc_reponse_nparray():
     assert sm.data.tensor.values == [1, 2, 3]
 
 
-def test_create_rest_reponse_text_ndarray():
+def test_create_rest_response_text_ndarray():
     user_model = UserObject()
     request_data = np.array([["hello", "world"], ["hello", "another", "world"]])
     request = {"data": {"ndarray": request_data, "names": []}}
@@ -96,7 +111,7 @@ def test_create_rest_reponse_text_ndarray():
     assert data_type == "data"
 
 
-def test_create_grpc_reponse_text_ndarray():
+def test_create_grpc_response_text_ndarray():
     user_model = UserObject()
     request_data = np.array([["hello", "world"], ["hello", "another", "world"]])
     datadef = scu.array_to_grpc_datadef("ndarray", request_data)
@@ -112,7 +127,7 @@ def test_create_grpc_reponse_text_ndarray():
     assert data_type == "data"
 
 
-def test_create_rest_reponse_ndarray():
+def test_create_rest_response_ndarray():
     user_model = UserObject()
     request = {"data": {"ndarray": np.array([[5, 6, 7]]), "names": []}}
     raw_response = np.array([[1, 2, 3]])
@@ -121,7 +136,7 @@ def test_create_rest_reponse_ndarray():
     assert np.array_equal(result["data"]["ndarray"], raw_response)
 
 
-def test_create_grpc_reponse_ndarray():
+def test_create_grpc_response_ndarray():
     user_model = UserObject()
     request_data = np.array([[5, 6, 7]])
     datadef = scu.array_to_grpc_datadef("ndarray", request_data)
@@ -131,7 +146,7 @@ def test_create_grpc_reponse_ndarray():
     assert sm.data.WhichOneof("data_oneof") == "ndarray"
 
 
-def test_create_rest_reponse_tensor():
+def test_create_rest_response_tensor():
     user_model = UserObject()
     tensor = {"values": [1, 2, 3], "shape": (3,)}
     request = {"data": {"tensor": tensor, "names": []}}
@@ -141,7 +156,7 @@ def test_create_rest_reponse_tensor():
     assert np.array_equal(result["data"]["tensor"], tensor)
 
 
-def test_create_grpc_reponse_tensor():
+def test_create_grpc_response_tensor():
     user_model = UserObject()
     request_data = np.array([[5, 6, 7]])
     datadef = scu.array_to_grpc_datadef("tensor", request_data)
@@ -233,7 +248,7 @@ def test_symmetric_json_conversion():
     assert json_request == result_json_request
 
 
-def test_create_grpc_reponse_list():
+def test_create_grpc_response_list():
     user_model = UserObject()
     request_data = np.array([[5, 6, 7]])
     datadef = scu.array_to_grpc_datadef("tensor", request_data)
@@ -243,7 +258,7 @@ def test_create_grpc_reponse_list():
     assert sm.data.WhichOneof("data_oneof") == "ndarray"
 
 
-def test_create_rest_reponse_binary():
+def test_create_rest_response_binary():
     user_model = UserObject()
     request_data = b"input"
     request = {"binData": request_data}
@@ -255,7 +270,7 @@ def test_create_rest_reponse_binary():
     assert sm["binData"] == resp_data
 
 
-def test_create_grpc_reponse_binary():
+def test_create_grpc_response_binary():
     user_model = UserObject()
     request_data = np.array([[5, 6, 7]])
     datadef = scu.array_to_grpc_datadef("tensor", request_data)
@@ -469,3 +484,67 @@ def test_getenv_as_bool(monkeypatch, env_val, expected):
 
     value = scu.getenv_as_bool(env_var, default=False)
     assert value == expected
+
+
+class TestEnvironmentVariables:
+    """
+    Tests for getting values from environment variables
+    """
+
+    @pytest.mark.parametrize(
+        "val, expected_val, env_var, getter",
+        [
+            (
+                "DUMMY_VAL_NAME",
+                "DUMMY_VAL_NAME",
+                ENV_SELDON_DEPLOYMENT_NAME,
+                get_deployment_name,
+            ),
+            ("DUMMY_VAL_NAME", "DUMMY_VAL_NAME", ENV_MODEL_NAME, get_model_name),
+            ("DUMMY_VAL_NAME", "DUMMY_VAL_NAME", ENV_MODEL_IMAGE, get_image_name),
+            (
+                "DUMMY_VAL_NAME",
+                "DUMMY_VAL_NAME",
+                ENV_PREDICTOR_NAME,
+                get_predictor_name,
+            ),
+            (
+                json.dumps({"key": "dummy", "version": "2"}),
+                "2",
+                ENV_PREDICTOR_LABELS,
+                get_predictor_version,
+            ),
+        ],
+    )
+    def test_get_deployment_name_ok(
+        self, monkeypatch, val, expected_val, env_var, getter
+    ):
+        monkeypatch.setenv(env_var, val)
+        assert getter() == expected_val
+
+    @pytest.mark.parametrize(
+        "val, getter",
+        [
+            (NONIMPLEMENTED_MSG, get_deployment_name),
+            (NONIMPLEMENTED_MSG, get_model_name),
+            (NONIMPLEMENTED_IMAGE_MSG, get_image_name),
+            (NONIMPLEMENTED_MSG, get_predictor_name),
+            (NONIMPLEMENTED_MSG, get_predictor_version),
+        ],
+    )
+    def test_env_notset_ok(self, val, getter):
+        assert getter() == val
+
+    @pytest.mark.parametrize(
+        "val, getter",
+        [
+            ("0", get_deployment_name),
+            ("0", get_model_name),
+            ("0", get_model_name),
+            ("0", get_image_name),
+            ("0", get_predictor_name),
+            ("0", get_predictor_version),
+        ],
+    )
+    def test_env_notset_with_default_ok(self, val, getter):
+        assert getter(default_val=val) == val
